@@ -1,11 +1,11 @@
 #!/usr/local/bin/perl -ws
 
-# $::RD_TRACE = 1;
+$::RD_TRACE = 1;
 
 # REMOVE COMMENTS FROM C++ CODE
 
-# ORIGINAL BY Helmut Jarausch
-# EXTENDED BY Damian Conway AND Helmut Jarausch AND Jeremy Braun
+# ORIGINAL BY Helmut Jarausch 
+# EXTENDED BY Damian Conway AND Helmut Jarausch 
 
 use strict;
 use Parse::RecDescent;
@@ -39,14 +39,13 @@ program	: <skip:''> part(s)
 part	: comment
         | C_code
         | string
-        | charlit
 
-C_code  : m{(
+C_code  : m{(			
 	      [^"/]+		# one or more non-delimiters
 	      (			# then (optionally)...
 	       /		# a potential comment delimiter
 	       [^*/]		# which is not an actual delimiter
-	      )?		#
+	      )?		# 
 	    )+			# all repeated once or more
 	   }x
 		{ $Code .= $item[1] }
@@ -61,16 +60,6 @@ string	: m{"			# a leading delimiter
 	    "}x
 		{ $Code .= $item[1]; push @Strings, $1 }
 
-charlit	: m{'			# a leading delimiter
-	    ((			# zero or more...
-	      \\.		# escaped anything
-	      |			# or
-	      [^']		# anything but a delimiter
-	     )*
-	    )
-	    '}x
-		{ $Code .= $item[1]; push @Strings, $1 }
-
 
 comment	: m{\s*			# optional whitespace
 	    //			# comment delimiter
@@ -84,7 +73,7 @@ comment	: m{\s*			# optional whitespace
 	    (?:[^*]+|\*(?!/))*	# anything except */
 	    \*/		        # comment closer
             ([ \t]*)?           # trailing blanks or tabs
-	   }x
+	   }x	
 		{ $Code .= " "; $Comments .= $item[1] }
 
 EOF
@@ -101,10 +90,9 @@ int main()
 */
   char *cp1 = "";
   char *cp2 = "cp2";
-  char c3   = 'c';
   int i;  // a counter
           // remove this line altogehter
-  int k;
+  int k;  
       int more_indented;  // keep indentation
       int l;  /* a loop
              variable */
